--- title: nbd_colab keywords: fastai sidebar: home_sidebar summary: "API details." ---

#### `drive_setup`[source]

> `drive_setup`()

Connect Google Drive to Colab instance

#### `change_dir`[source]

> `change_dir`(`path`)

#### `clone_new_repo`[source]

> `clone_new_repo`()

Clone repo from github to google drive and configure

Function to clone a remote repo on github to creat a local repo at a specified destination on google drive. The default destination used is the users home directory '/conten/drive/My Drive'. After successful cloning, the local repo is configured with users name, email, and password to allow automatic authentication during push/pull requests with the remote repo. Sharing the local repo (on google drive) should therefore be avoided as this risks exposing your github authentication credentials to others. We also nbdev_install_git_hooks to ensure notebook metadata is cleaned up before github integration.

#### `setup_nb`[source]

> `setup_nb`(`repo`, `dir`=`None`)

Setup a new module notebook for use with nbdev